@@ -12,9 +12,10 @@ def comp_axes(self, axes_list):
         a list of RequestedAxis objects
     Returns
     -------
-    list of RequestedAxis objects
+    list of RequestedAxis objects + transformations
     """
     
+    transforms = []
     # Check if the requested axis is defined in the Data object
     for axis_requested in axes_list[:]:
         axis_name = axis_requested.name
@@ -23,6 +24,10 @@ def comp_axes(self, axes_list):
                 axis_requested.index = index
                 axis_requested.corr_name = axis_name
                 axis_requested.corr_unit = axis.unit
+                if axis_name in rev_axes_dict.keys():
+                    transforms.append(rev_axes_dict[axis_name][1])
+                if axis_name in axes_dict.keys():
+                    axis_requested.transform = axes_dict[axis_name][1]
         if axis_requested.index is None:
             # Check if requested axis is in correspondance dicts
             if axis_name in axes_dict.keys():
@@ -32,6 +37,7 @@ def comp_axes(self, axes_list):
                         axis_requested.corr_unit = axes_dict[axis_name][2]
                         axis_requested.operation = axes_dict[axis_name][0]+"_to_"+axis_name
                         axis_requested.transform = axes_dict[axis_name][1]
+                        transforms.append(axes_dict[axis_name][1])
                         axis_requested.index = index
                 if axis_requested.index is None:
                     # Axis does not exist and is ignored
@@ -43,6 +49,7 @@ def comp_axes(self, axes_list):
                         axis_requested.corr_unit = rev_axes_dict[axis_name][2]
                         axis_requested.operation = rev_axes_dict[axis_name][0]+"_to_"+axis_name
                         axis_requested.transform = rev_axes_dict[axis_name][1]
+                        transforms.append(rev_axes_dict[axis_name][1])
                         axis_requested.index = index
                 if axis_requested.index is None:
                     # Axis does not exist and is ignored
@@ -53,5 +60,5 @@ def comp_axes(self, axes_list):
     # Extract the requested axes (symmetries + unit)
     for axis_requested in axes_list:
         axis_requested.get_axis(self.axes[axis_requested.index], self.normalizations)
-    return axes_list
+    return axes_list, transforms
         
\ No newline at end of file
